==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/is.pl <==
{
  am_pm_abbreviated => [
    "f.h.",
    "e.h.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d.",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "v \N{U+2013} HH:mm:ss",
    Hmv => "v \N{U+2013} HH:mm",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-one" => "'viku' W '\N{U+00ed}' MMMM",
    "MMMMW-count-other" => "'viku' W '\N{U+00ed}' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M. y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'viku' w 'af' Y",
    "yw-count-other" => "'viku' w 'af' Y",
  },
  code => "is",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "d.M.y",
  datetime_format_full => "{1} 'kl'. {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "m\N{U+00e1}n.",
    "\N{U+00fe}ri.",
    "mi\N{U+00f0}.",
    "fim.",
    "f\N{U+00f6}s.",
    "lau.",
    "sun.",
  ],
  day_format_narrow => [
    "M",
    "\N{U+00de}",
    "M",
    "F",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "m\N{U+00e1}nudagur",
    "\N{U+00fe}ri\N{U+00f0}judagur",
    "mi\N{U+00f0}vikudagur",
    "fimmtudagur",
    "f\N{U+00f6}studagur",
    "laugardagur",
    "sunnudagur",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+00e1}n.",
    "\N{U+00fe}ri.",
    "mi\N{U+00f0}.",
    "fim.",
    "f\N{U+00f6}s.",
    "lau.",
    "sun.",
  ],
  day_stand_alone_narrow => [
    "M",
    "\N{U+00de}",
    "M",
    "F",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "m\N{U+00e1}nudagur",
    "\N{U+00fe}ri\N{U+00f0}judagur",
    "mi\N{U+00f0}vikudagur",
    "fimmtudagur",
    "f\N{U+00f6}studagur",
    "laugardagur",
    "sunnudagur",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "f.k.",
    "e.k.",
  ],
  era_wide => [
    "fyrir Krist",
    "eftir Krist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Icelandic",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "ma\N{U+00ed}",
    "j\N{U+00fa}n.",
    "j\N{U+00fa}l.",
    "\N{U+00e1}g\N{U+00fa}.",
    "sep.",
    "okt.",
    "n\N{U+00f3}v.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "\N{U+00c1}",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "jan\N{U+00fa}ar",
    "febr\N{U+00fa}ar",
    "mars",
    "apr\N{U+00ed}l",
    "ma\N{U+00ed}",
    "j\N{U+00fa}n\N{U+00ed}",
    "j\N{U+00fa}l\N{U+00ed}",
    "\N{U+00e1}g\N{U+00fa}st",
    "september",
    "okt\N{U+00f3}ber",
    "n\N{U+00f3}vember",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "ma\N{U+00ed}",
    "j\N{U+00fa}n.",
    "j\N{U+00fa}l.",
    "\N{U+00e1}g\N{U+00fa}.",
    "sep.",
    "okt.",
    "n\N{U+00f3}v.",
    "des.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "\N{U+00c1}",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "jan\N{U+00fa}ar",
    "febr\N{U+00fa}ar",
    "mars",
    "apr\N{U+00ed}l",
    "ma\N{U+00ed}",
    "j\N{U+00fa}n\N{U+00ed}",
    "j\N{U+00fa}l\N{U+00ed}",
    "\N{U+00e1}g\N{U+00fa}st",
    "september",
    "okt\N{U+00f3}ber",
    "n\N{U+00f3}vember",
    "desember",
  ],
  name => "Icelandic",
  native_language => "\N{U+00ed}slenska",
  native_name => "\N{U+00ed}slenska",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "F1",
    "F2",
    "F3",
    "F4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. fj\N{U+00f3}r\N{U+00f0}ungur",
    "2. fj\N{U+00f3}r\N{U+00f0}ungur",
    "3. fj\N{U+00f3}r\N{U+00f0}ungur",
    "4. fj\N{U+00f3}r\N{U+00f0}ungur",
  ],
  quarter_stand_alone_abbreviated => [
    "F1",
    "F2",
    "F3",
    "F4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. fj\N{U+00f3}r\N{U+00f0}ungur",
    "2. fj\N{U+00f3}r\N{U+00f0}ungur",
    "3. fj\N{U+00f3}r\N{U+00f0}ungur",
    "4. fj\N{U+00f3}r\N{U+00f0}ungur",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/is.pl <==
{
  am_pm_abbreviated => [
    "f.h.",
    "e.h.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E d.",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "v \N{U+2013} HH:mm:ss",
    Hmv => "v \N{U+2013} HH:mm",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-one" => "'viku' W '\N{U+00ed}' MMMM",
    "MMMMW-count-other" => "'viku' W '\N{U+00ed}' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "d.M.",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M. y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'viku' w 'af' Y",
    "yw-count-other" => "'viku' w 'af' Y",
  },
  code => "is",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "d.M.y",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "m\N{U+00e1}n.",
    "\N{U+00fe}ri.",
    "mi\N{U+00f0}.",
    "fim.",
    "f\N{U+00f6}s.",
    "lau.",
    "sun.",
  ],
  day_format_narrow => [
    "M",
    "\N{U+00de}",
    "M",
    "F",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "m\N{U+00e1}nudagur",
    "\N{U+00fe}ri\N{U+00f0}judagur",
    "mi\N{U+00f0}vikudagur",
    "fimmtudagur",
    "f\N{U+00f6}studagur",
    "laugardagur",
    "sunnudagur",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+00e1}n.",
    "\N{U+00fe}ri.",
    "mi\N{U+00f0}.",
    "fim.",
    "f\N{U+00f6}s.",
    "lau.",
    "sun.",
  ],
  day_stand_alone_narrow => [
    "M",
    "\N{U+00de}",
    "M",
    "F",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "m\N{U+00e1}nudagur",
    "\N{U+00fe}ri\N{U+00f0}judagur",
    "mi\N{U+00f0}vikudagur",
    "fimmtudagur",
    "f\N{U+00f6}studagur",
    "laugardagur",
    "sunnudagur",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "f.k.",
    "e.k.",
  ],
  era_wide => [
    "fyrir Krist",
    "eftir Krist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Icelandic",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "ma\N{U+00ed}",
    "j\N{U+00fa}n.",
    "j\N{U+00fa}l.",
    "\N{U+00e1}g\N{U+00fa}.",
    "sep.",
    "okt.",
    "n\N{U+00f3}v.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "\N{U+00c1}",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "jan\N{U+00fa}ar",
    "febr\N{U+00fa}ar",
    "mars",
    "apr\N{U+00ed}l",
    "ma\N{U+00ed}",
    "j\N{U+00fa}n\N{U+00ed}",
    "j\N{U+00fa}l\N{U+00ed}",
    "\N{U+00e1}g\N{U+00fa}st",
    "september",
    "okt\N{U+00f3}ber",
    "n\N{U+00f3}vember",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "ma\N{U+00ed}",
    "j\N{U+00fa}n.",
    "j\N{U+00fa}l.",
    "\N{U+00e1}g\N{U+00fa}.",
    "sep.",
    "okt.",
    "n\N{U+00f3}v.",
    "des.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "\N{U+00c1}",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "jan\N{U+00fa}ar",
    "febr\N{U+00fa}ar",
    "mars",
    "apr\N{U+00ed}l",
    "ma\N{U+00ed}",
    "j\N{U+00fa}n\N{U+00ed}",
    "j\N{U+00fa}l\N{U+00ed}",
    "\N{U+00e1}g\N{U+00fa}st",
    "september",
    "okt\N{U+00f3}ber",
    "n\N{U+00f3}vember",
    "desember",
  ],
  name => "Icelandic",
  native_language => "\N{U+00ed}slenska",
  native_name => "\N{U+00ed}slenska",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "F1",
    "F2",
    "F3",
    "F4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. fj\N{U+00f3}r\N{U+00f0}ungur",
    "2. fj\N{U+00f3}r\N{U+00f0}ungur",
    "3. fj\N{U+00f3}r\N{U+00f0}ungur",
    "4. fj\N{U+00f3}r\N{U+00f0}ungur",
  ],
  quarter_stand_alone_abbreviated => [
    "F1",
    "F2",
    "F3",
    "F4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. fj\N{U+00f3}r\N{U+00f0}ungur",
    "2. fj\N{U+00f3}r\N{U+00f0}ungur",
    "3. fj\N{U+00f3}r\N{U+00f0}ungur",
    "4. fj\N{U+00f3}r\N{U+00f0}ungur",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
